/*
 * Written by Hanson Char and released to the public domain,
 * as explained at http://creativecommons.org/licenses/publicdomain
 */
package net.sf.beanlib.util.concurrent;

import java.util.Queue;
import java.util.concurrent.ExecutionException;
import java.util.concurrent.LinkedBlockingQueue;
import java.util.concurrent.TimeUnit;

/**
 * Used to test the performance of LinkedBlockingQueue.
 * 
 * @see ConcurrentLinkedBlockingQueueTestMain
 * @author Hanson Char
 */
public class LinkedBlockingQueueTestMain extends AbstractBlockingQueueTestMain 
{
    private final LinkedBlockingQueue<Integer> q = new LinkedBlockingQueue<Integer>();
    private volatile int count;
    
    @Override
    protected Queue<Integer> getQueue() {
        return q;
    }
    
    @Override
    protected CallableWithCount<Void> newConumerCallable() {
        return new CallableWithCount<Void>()
        {
            public Void call() throws InterruptedException 
            {
                while (getTotalConsumedCount() < TOTAL)
                    if (q.poll(1, TimeUnit.MILLISECONDS) != null)
                        count++;
                    else
                        continue;
                return null;
            }
            
            public int getCount() {
                return count;
            }
        };
    }
    
    public static void main(String[] args) throws InterruptedException, ExecutionException
    {
        new LinkedBlockingQueueTestMain().call();
        System.exit(0);
    }
}
